aboutsummaryrefslogtreecommitdiffstats
path: root/include/linux/hsi_driver_if.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/linux/hsi_driver_if.h')
-rw-r--r--include/linux/hsi_driver_if.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/include/linux/hsi_driver_if.h b/include/linux/hsi_driver_if.h
index 547b30e..6e7a0da 100644
--- a/include/linux/hsi_driver_if.h
+++ b/include/linux/hsi_driver_if.h
@@ -29,7 +29,7 @@
/* The number of ports handled by the driver (MAX:2). Reducing this value
* optimizes the driver memory footprint.
*/
-#define HSI_MAX_PORTS 1
+#define HSI_MAX_PORTS 2
/* bit-field definition for allowed controller IDs and channels */
#define ANY_HSI_CONTROLLER -1
@@ -62,10 +62,8 @@ enum {
HSI_IOCTL_GET_TX, /* Get HST configuration */
HSI_IOCTL_SW_RESET, /* Force a HSI SW RESET */
HSI_IOCTL_GET_FIFO_OCCUPANCY, /* Get amount of words in RX FIFO */
- HSI_IOCTL_SET_ACREADY_SAFEMODE,
- HSI_IOCTL_SET_ACREADY_NORMAL,
- HSI_IOCTL_SET_3WIRE_MODE,
- HSI_IOCTL_SET_4WIRE_MODE,
+ HSI_IOCTL_SET_WAKE_RX_3WIRES_MODE, /* Enable RX wakeup 3-wires mode */
+ HSI_IOCTL_SET_WAKE_RX_4WIRES_MODE, /* Enable RX wakeup 4-wires mode */
};
/* Forward references */
@@ -91,28 +89,30 @@ struct hsr_ctx {
u32 channels;
};
-struct port_ctx {
+struct hsi_port_ctx {
+ int port_number; /* Range [1, 2] */
u32 sys_mpu_enable[2];
struct hst_ctx hst;
struct hsr_ctx hsr;
+ const char *cawake_padconf_name;
+ int cawake_padconf_hsi_mode;
};
/**
* struct ctrl_ctx - hsi controller regs context
* @sysconfig: keeps HSI_SYSCONFIG reg state
* @gdd_gcr: keeps DMA_GCR reg state
* @dll: keeps HSR_DLL state
* @pctx: array of port context
*/
-struct ctrl_ctx {
+struct hsi_ctrl_ctx {
u32 sysconfig;
u32 gdd_gcr;
u32 dll;
- struct port_ctx *pctx;
+ struct hsi_port_ctx *pctx;
};
/* END DPS */
-
/**
* struct hsi_device - HSI device object (Virtual)
* @n_ctrl: associated HSI controller platform id number
@@ -91,28 +89,30 @@ struct hsr_ctx {
};
/**
- * struct ctrl_ctx - hsi controller regs context
+ * struct hsi_ctrl_ctx - hsi controller regs context
* @sysconfig: keeps HSI_SYSCONFIG reg state
* @gdd_gcr: keeps DMA_GCR reg state